NoteCommitmentUpdate

Type Alias NoteCommitmentUpdate 

pub type NoteCommitmentUpdate = Base;
The type that is used to update the note commitment tree.

Unfortunately, this is not the same as orchard::NoteCommitment.

Aliased Type

#[repr(transparent)]
pub struct NoteCommitmentUpdate(/* private fields */);

Layout

Note: Most layout information is completely unstable and may even differ between compilations. The only exception is types with certain repr(...) attributes. Please see the Rust Reference's “Type Layout” chapter for details on type layout guarantees.

Size: 32 bytes